# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: mubit/v1/core.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'mubit/v1/core.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13mubit/v1/core.proto\x12\x08mubit.v1\"3\n\x11\x43reateUserRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\"G\n\x12\x43reateUserResponse\x12\x0f\n\x07user_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"+\n\x17RotateUserApiKeyRequest\x12\x10\n\x08username\x18\x01 \x01(\t\"M\n\x18RotateUserApiKeyResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"+\n\x17RevokeUserApiKeyRequest\x12\x10\n\x08username\x18\x01 \x01(\t\"<\n\x18RevokeUserApiKeyResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x12\n\x10ListUsersRequest\"h\n\x08\x41uthUser\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\x04\x12\x0c\n\x04role\x18\x03 \x01(\t\x12\x13\n\x0binstance_id\x18\x04 \x01(\t\x12\x16\n\x0e\x61pi_key_active\x18\x05 \x01(\x08\"6\n\x11ListUsersResponse\x12!\n\x05users\x18\x01 \x03(\x0b\x32\x12.mubit.v1.AuthUser\"\"\n\x0eGetUserRequest\x12\x10\n\x08username\x18\x01 \x01(\t\"3\n\x0fGetUserResponse\x12 \n\x04user\x18\x01 \x01(\x0b\x32\x12.mubit.v1.AuthUser\"%\n\x11\x44\x65leteUserRequest\x12\x10\n\x08username\x18\x01 \x01(\t\"6\n\x12\x44\x65leteUserResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x0f\n\rHealthRequest\"1\n\x0eHealthResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"D\n\x04Node\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x10\n\x08metadata\x18\x03 \x01(\x0c\x12\x13\n\x06run_id\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_run_id\"\xa7\x01\n\rInsertRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x10\n\x08metadata\x18\x03 \x01(\x0c\x12\x0f\n\x07user_id\x18\x04 \x01(\x04\x12\x17\n\nsession_id\x18\x05 \x01(\tH\x00\x88\x01\x01\x12\x11\n\tembedding\x18\x06 \x03(\x02\x12\x13\n\x06run_id\x18\x07 \x01(\tH\x01\x88\x01\x01\x42\r\n\x0b_session_idB\t\n\x07_run_id\"C\n\x0eInsertResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07node_id\x18\x02 \x01(\x04\x12\x0f\n\x07message\x18\x03 \x01(\t\"6\n\x13\x42\x61tchInsertResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\r\x12\x10\n\x08node_ids\x18\x02 \x03(\x04\"!\n\x0eGetNodeRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\x04\"/\n\x0fGetNodeResponse\x12\x1c\n\x04node\x18\x01 \x01(\x0b\x32\x0e.mubit.v1.Node\"L\n\x11\x44\x65leteNodeRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\x04\x12\x17\n\nsession_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\r\n\x0b_session_id\"6\n\x12\x44\x65leteNodeResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"3\n\x10\x44\x65leteRunRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\x04\"D\n\x11\x44\x65leteRunResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x04\"\xb0\x01\n\rSearchRequest\x12\x12\n\nquery_text\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\x04\x12\t\n\x01k\x18\x03 \x01(\r\x12\x17\n\nsession_id\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x0e\n\x06\x66ilter\x18\x05 \x01(\t\x12\x17\n\x0fquery_embedding\x18\x06 \x03(\x02\x12\x13\n\x06run_id\x18\x07 \x01(\tH\x01\x88\x01\x01\x42\r\n\x0b_session_idB\t\n\x07_run_id\"9\n\x0eSearchResponse\x12\'\n\x07results\x18\x01 \x03(\x0b\x32\x16.mubit.v1.SearchResult\"@\n\x0cSearchResult\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x12\n\nsimilarity\x18\x02 \x01(\x02\x12\x10\n\x08metadata\x18\x03 \x01(\x0c\":\n\x0bPermissions\x12\x0c\n\x04read\x18\x01 \x01(\x08\x12\r\n\x05write\x18\x02 \x01(\x08\x12\x0e\n\x06\x64\x65lete\x18\x03 \x01(\x08\"m\n\x16GrantPermissionRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\x04\x12\x16\n\x0etarget_user_id\x18\x02 \x01(\x04\x12*\n\x0bpermissions\x18\x03 \x01(\x0b\x32\x15.mubit.v1.Permissions\";\n\x17GrantPermissionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"B\n\x17RevokePermissionRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\x04\x12\x16\n\x0etarget_user_id\x18\x02 \x01(\x04\"<\n\x18RevokePermissionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x97\x01\n\x14\x43oreSubscribeRequest\x12\x13\n\x0b\x66ilter_type\x18\x01 \x01(\t\x12\x14\n\x07node_id\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\x0e\n\x06vector\x18\x03 \x03(\x02\x12\x16\n\tthreshold\x18\x04 \x01(\x02H\x01\x88\x01\x01\x12\x12\n\nquery_text\x18\x05 \x01(\tB\n\n\x08_node_idB\x0c\n\n_threshold\"J\n\x0bPubSubEvent\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x1c\n\x04node\x18\x02 \x01(\x0b\x32\x0e.mubit.v1.Node\x12\x0f\n\x07node_id\x18\x03 \x01(\x04\"\x1b\n\tBitVector\x12\x0e\n\x06\x63hunks\x18\x01 \x03(\x04\"n\n\x12WriteMemoryRequest\x12$\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x13.mubit.v1.BitVector\x12!\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x13.mubit.v1.BitVector\x12\x0f\n\x07user_id\x18\x03 \x01(\x04\"7\n\x13WriteMemoryResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"J\n\x11ReadMemoryRequest\x12$\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x13.mubit.v1.BitVector\x12\x0f\n\x07user_id\x18\x02 \x01(\x04\"7\n\x12ReadMemoryResponse\x12!\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x13.mubit.v1.BitVector\"\xf3\x01\n\x0bMemoryEntry\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x05 \x01(\x03\x12\x35\n\x08metadata\x18\x06 \x03(\x0b\x32#.mubit.v1.MemoryEntry.MetadataEntry\x12\x17\n\nexpires_at\x18\x07 \x01(\x03H\x00\x88\x01\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\r\n\x0b_expires_at\"\xe0\x01\n\x10\x41\x64\x64MemoryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12:\n\x08metadata\x18\x04 \x03(\x0b\x32(.mubit.v1.AddMemoryRequest.MetadataEntry\x12\x18\n\x0bttl_seconds\x18\x05 \x01(\x03H\x00\x88\x01\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0e\n\x0c_ttl_seconds\"[\n\x11\x41\x64\x64MemoryResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12$\n\x05\x65ntry\x18\x03 \x01(\x0b\x32\x15.mubit.v1.MemoryEntry\"\xb5\x01\n\x10GetMemoryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\r\x12\x17\n\x0f\x61\x66ter_timestamp\x18\x03 \x01(\x03\x12\x36\n\x06\x66ilter\x18\x04 \x03(\x0b\x32&.mubit.v1.GetMemoryRequest.FilterEntry\x1a-\n\x0b\x46ilterEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\";\n\x11GetMemoryResponse\x12&\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x15.mubit.v1.MemoryEntry\"(\n\x12\x43learMemoryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"7\n\x13\x43learMemoryResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"(\n\x12WatchMemoryRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"A\n\x0bMemoryEvent\x12\x0c\n\x04type\x18\x01 \x01(\t\x12$\n\x05\x65ntry\x18\x02 \x01(\x0b\x32\x15.mubit.v1.MemoryEntry\"L\n\x14\x43reateSessionRequest\x12\x1e\n\x11parent_session_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x14\n\x12_parent_session_id\"+\n\x15\x43reateSessionResponse\x12\x12\n\nsession_id\x18\x01 \x01(\t\":\n\x16SnapshotSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"*\n\x17SnapshotSessionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\"\n\x12LoadSessionRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\")\n\x13LoadSessionResponse\x12\x12\n\nsession_id\x18\x01 \x01(\t\"B\n\x14\x43ommitSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x16\n\x0emerge_strategy\x18\x02 \x01(\t\"(\n\x15\x43ommitSessionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"(\n\x12\x44ropSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"&\n\x13\x44ropSessionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32\xad\x10\n\x0b\x43oreService\x12G\n\nCreateUser\x12\x1b.mubit.v1.CreateUserRequest\x1a\x1c.mubit.v1.CreateUserResponse\x12Y\n\x10RotateUserApiKey\x12!.mubit.v1.RotateUserApiKeyRequest\x1a\".mubit.v1.RotateUserApiKeyResponse\x12Y\n\x10RevokeUserApiKey\x12!.mubit.v1.RevokeUserApiKeyRequest\x1a\".mubit.v1.RevokeUserApiKeyResponse\x12\x44\n\tListUsers\x12\x1a.mubit.v1.ListUsersRequest\x1a\x1b.mubit.v1.ListUsersResponse\x12>\n\x07GetUser\x12\x18.mubit.v1.GetUserRequest\x1a\x19.mubit.v1.GetUserResponse\x12G\n\nDeleteUser\x12\x1b.mubit.v1.DeleteUserRequest\x1a\x1c.mubit.v1.DeleteUserResponse\x12;\n\x06Health\x12\x17.mubit.v1.HealthRequest\x1a\x18.mubit.v1.HealthResponse\x12;\n\x06Insert\x12\x17.mubit.v1.InsertRequest\x1a\x18.mubit.v1.InsertResponse\x12>\n\x07GetNode\x12\x18.mubit.v1.GetNodeRequest\x1a\x19.mubit.v1.GetNodeResponse\x12G\n\nDeleteNode\x12\x1b.mubit.v1.DeleteNodeRequest\x1a\x1c.mubit.v1.DeleteNodeResponse\x12\x44\n\tDeleteRun\x12\x1a.mubit.v1.DeleteRunRequest\x1a\x1b.mubit.v1.DeleteRunResponse\x12;\n\x06Search\x12\x17.mubit.v1.SearchRequest\x1a\x18.mubit.v1.SearchResponse\x12G\n\x0b\x42\x61tchInsert\x12\x17.mubit.v1.InsertRequest\x1a\x1d.mubit.v1.BatchInsertResponse(\x01\x12\x41\n\x0cStreamSearch\x12\x17.mubit.v1.SearchRequest\x1a\x16.mubit.v1.SearchResult0\x01\x12V\n\x0fGrantPermission\x12 .mubit.v1.GrantPermissionRequest\x1a!.mubit.v1.GrantPermissionResponse\x12Y\n\x10RevokePermission\x12!.mubit.v1.RevokePermissionRequest\x1a\".mubit.v1.RevokePermissionResponse\x12\x44\n\tSubscribe\x12\x1e.mubit.v1.CoreSubscribeRequest\x1a\x15.mubit.v1.PubSubEvent0\x01\x12J\n\x0bWriteMemory\x12\x1c.mubit.v1.WriteMemoryRequest\x1a\x1d.mubit.v1.WriteMemoryResponse\x12G\n\nReadMemory\x12\x1b.mubit.v1.ReadMemoryRequest\x1a\x1c.mubit.v1.ReadMemoryResponse\x12\x44\n\tAddMemory\x12\x1a.mubit.v1.AddMemoryRequest\x1a\x1b.mubit.v1.AddMemoryResponse\x12\x44\n\tGetMemory\x12\x1a.mubit.v1.GetMemoryRequest\x1a\x1b.mubit.v1.GetMemoryResponse\x12J\n\x0b\x43learMemory\x12\x1c.mubit.v1.ClearMemoryRequest\x1a\x1d.mubit.v1.ClearMemoryResponse\x12\x44\n\x0bWatchMemory\x12\x1c.mubit.v1.WatchMemoryRequest\x1a\x15.mubit.v1.MemoryEvent0\x01\x12P\n\rCreateSession\x12\x1e.mubit.v1.CreateSessionRequest\x1a\x1f.mubit.v1.CreateSessionResponse\x12V\n\x0fSnapshotSession\x12 .mubit.v1.SnapshotSessionRequest\x1a!.mubit.v1.SnapshotSessionResponse\x12J\n\x0bLoadSession\x12\x1c.mubit.v1.LoadSessionRequest\x1a\x1d.mubit.v1.LoadSessionResponse\x12P\n\rCommitSession\x12\x1e.mubit.v1.CommitSessionRequest\x1a\x1f.mubit.v1.CommitSessionResponse\x12J\n\x0b\x44ropSession\x12\x1c.mubit.v1.DropSessionRequest\x1a\x1d.mubit.v1.DropSessionResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mubit.v1.core_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MEMORYENTRY_METADATAENTRY']._loaded_options = None
  _globals['_MEMORYENTRY_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_ADDMEMORYREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_ADDMEMORYREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GETMEMORYREQUEST_FILTERENTRY']._loaded_options = None
  _globals['_GETMEMORYREQUEST_FILTERENTRY']._serialized_options = b'8\001'
  _globals['_CREATEUSERREQUEST']._serialized_start=33
  _globals['_CREATEUSERREQUEST']._serialized_end=84
  _globals['_CREATEUSERRESPONSE']._serialized_start=86
  _globals['_CREATEUSERRESPONSE']._serialized_end=157
  _globals['_ROTATEUSERAPIKEYREQUEST']._serialized_start=159
  _globals['_ROTATEUSERAPIKEYREQUEST']._serialized_end=202
  _globals['_ROTATEUSERAPIKEYRESPONSE']._serialized_start=204
  _globals['_ROTATEUSERAPIKEYRESPONSE']._serialized_end=281
  _globals['_REVOKEUSERAPIKEYREQUEST']._serialized_start=283
  _globals['_REVOKEUSERAPIKEYREQUEST']._serialized_end=326
  _globals['_REVOKEUSERAPIKEYRESPONSE']._serialized_start=328
  _globals['_REVOKEUSERAPIKEYRESPONSE']._serialized_end=388
  _globals['_LISTUSERSREQUEST']._serialized_start=390
  _globals['_LISTUSERSREQUEST']._serialized_end=408
  _globals['_AUTHUSER']._serialized_start=410
  _globals['_AUTHUSER']._serialized_end=514
  _globals['_LISTUSERSRESPONSE']._serialized_start=516
  _globals['_LISTUSERSRESPONSE']._serialized_end=570
  _globals['_GETUSERREQUEST']._serialized_start=572
  _globals['_GETUSERREQUEST']._serialized_end=606
  _globals['_GETUSERRESPONSE']._serialized_start=608
  _globals['_GETUSERRESPONSE']._serialized_end=659
  _globals['_DELETEUSERREQUEST']._serialized_start=661
  _globals['_DELETEUSERREQUEST']._serialized_end=698
  _globals['_DELETEUSERRESPONSE']._serialized_start=700
  _globals['_DELETEUSERRESPONSE']._serialized_end=754
  _globals['_HEALTHREQUEST']._serialized_start=756
  _globals['_HEALTHREQUEST']._serialized_end=771
  _globals['_HEALTHRESPONSE']._serialized_start=773
  _globals['_HEALTHRESPONSE']._serialized_end=822
  _globals['_NODE']._serialized_start=824
  _globals['_NODE']._serialized_end=892
  _globals['_INSERTREQUEST']._serialized_start=895
  _globals['_INSERTREQUEST']._serialized_end=1062
  _globals['_INSERTRESPONSE']._serialized_start=1064
  _globals['_INSERTRESPONSE']._serialized_end=1131
  _globals['_BATCHINSERTRESPONSE']._serialized_start=1133
  _globals['_BATCHINSERTRESPONSE']._serialized_end=1187
  _globals['_GETNODEREQUEST']._serialized_start=1189
  _globals['_GETNODEREQUEST']._serialized_end=1222
  _globals['_GETNODERESPONSE']._serialized_start=1224
  _globals['_GETNODERESPONSE']._serialized_end=1271
  _globals['_DELETENODEREQUEST']._serialized_start=1273
  _globals['_DELETENODEREQUEST']._serialized_end=1349
  _globals['_DELETENODERESPONSE']._serialized_start=1351
  _globals['_DELETENODERESPONSE']._serialized_end=1405
  _globals['_DELETERUNREQUEST']._serialized_start=1407
  _globals['_DELETERUNREQUEST']._serialized_end=1458
  _globals['_DELETERUNRESPONSE']._serialized_start=1460
  _globals['_DELETERUNRESPONSE']._serialized_end=1528
  _globals['_SEARCHREQUEST']._serialized_start=1531
  _globals['_SEARCHREQUEST']._serialized_end=1707
  _globals['_SEARCHRESPONSE']._serialized_start=1709
  _globals['_SEARCHRESPONSE']._serialized_end=1766
  _globals['_SEARCHRESULT']._serialized_start=1768
  _globals['_SEARCHRESULT']._serialized_end=1832
  _globals['_PERMISSIONS']._serialized_start=1834
  _globals['_PERMISSIONS']._serialized_end=1892
  _globals['_GRANTPERMISSIONREQUEST']._serialized_start=1894
  _globals['_GRANTPERMISSIONREQUEST']._serialized_end=2003
  _globals['_GRANTPERMISSIONRESPONSE']._serialized_start=2005
  _globals['_GRANTPERMISSIONRESPONSE']._serialized_end=2064
  _globals['_REVOKEPERMISSIONREQUEST']._serialized_start=2066
  _globals['_REVOKEPERMISSIONREQUEST']._serialized_end=2132
  _globals['_REVOKEPERMISSIONRESPONSE']._serialized_start=2134
  _globals['_REVOKEPERMISSIONRESPONSE']._serialized_end=2194
  _globals['_CORESUBSCRIBEREQUEST']._serialized_start=2197
  _globals['_CORESUBSCRIBEREQUEST']._serialized_end=2348
  _globals['_PUBSUBEVENT']._serialized_start=2350
  _globals['_PUBSUBEVENT']._serialized_end=2424
  _globals['_BITVECTOR']._serialized_start=2426
  _globals['_BITVECTOR']._serialized_end=2453
  _globals['_WRITEMEMORYREQUEST']._serialized_start=2455
  _globals['_WRITEMEMORYREQUEST']._serialized_end=2565
  _globals['_WRITEMEMORYRESPONSE']._serialized_start=2567
  _globals['_WRITEMEMORYRESPONSE']._serialized_end=2622
  _globals['_READMEMORYREQUEST']._serialized_start=2624
  _globals['_READMEMORYREQUEST']._serialized_end=2698
  _globals['_READMEMORYRESPONSE']._serialized_start=2700
  _globals['_READMEMORYRESPONSE']._serialized_end=2755
  _globals['_MEMORYENTRY']._serialized_start=2758
  _globals['_MEMORYENTRY']._serialized_end=3001
  _globals['_MEMORYENTRY_METADATAENTRY']._serialized_start=2939
  _globals['_MEMORYENTRY_METADATAENTRY']._serialized_end=2986
  _globals['_ADDMEMORYREQUEST']._serialized_start=3004
  _globals['_ADDMEMORYREQUEST']._serialized_end=3228
  _globals['_ADDMEMORYREQUEST_METADATAENTRY']._serialized_start=2939
  _globals['_ADDMEMORYREQUEST_METADATAENTRY']._serialized_end=2986
  _globals['_ADDMEMORYRESPONSE']._serialized_start=3230
  _globals['_ADDMEMORYRESPONSE']._serialized_end=3321
  _globals['_GETMEMORYREQUEST']._serialized_start=3324
  _globals['_GETMEMORYREQUEST']._serialized_end=3505
  _globals['_GETMEMORYREQUEST_FILTERENTRY']._serialized_start=3460
  _globals['_GETMEMORYREQUEST_FILTERENTRY']._serialized_end=3505
  _globals['_GETMEMORYRESPONSE']._serialized_start=3507
  _globals['_GETMEMORYRESPONSE']._serialized_end=3566
  _globals['_CLEARMEMORYREQUEST']._serialized_start=3568
  _globals['_CLEARMEMORYREQUEST']._serialized_end=3608
  _globals['_CLEARMEMORYRESPONSE']._serialized_start=3610
  _globals['_CLEARMEMORYRESPONSE']._serialized_end=3665
  _globals['_WATCHMEMORYREQUEST']._serialized_start=3667
  _globals['_WATCHMEMORYREQUEST']._serialized_end=3707
  _globals['_MEMORYEVENT']._serialized_start=3709
  _globals['_MEMORYEVENT']._serialized_end=3774
  _globals['_CREATESESSIONREQUEST']._serialized_start=3776
  _globals['_CREATESESSIONREQUEST']._serialized_end=3852
  _globals['_CREATESESSIONRESPONSE']._serialized_start=3854
  _globals['_CREATESESSIONRESPONSE']._serialized_end=3897
  _globals['_SNAPSHOTSESSIONREQUEST']._serialized_start=3899
  _globals['_SNAPSHOTSESSIONREQUEST']._serialized_end=3957
  _globals['_SNAPSHOTSESSIONRESPONSE']._serialized_start=3959
  _globals['_SNAPSHOTSESSIONRESPONSE']._serialized_end=4001
  _globals['_LOADSESSIONREQUEST']._serialized_start=4003
  _globals['_LOADSESSIONREQUEST']._serialized_end=4037
  _globals['_LOADSESSIONRESPONSE']._serialized_start=4039
  _globals['_LOADSESSIONRESPONSE']._serialized_end=4080
  _globals['_COMMITSESSIONREQUEST']._serialized_start=4082
  _globals['_COMMITSESSIONREQUEST']._serialized_end=4148
  _globals['_COMMITSESSIONRESPONSE']._serialized_start=4150
  _globals['_COMMITSESSIONRESPONSE']._serialized_end=4190
  _globals['_DROPSESSIONREQUEST']._serialized_start=4192
  _globals['_DROPSESSIONREQUEST']._serialized_end=4232
  _globals['_DROPSESSIONRESPONSE']._serialized_start=4234
  _globals['_DROPSESSIONRESPONSE']._serialized_end=4272
  _globals['_CORESERVICE']._serialized_start=4275
  _globals['_CORESERVICE']._serialized_end=6368
# @@protoc_insertion_point(module_scope)
