# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: mubit/v1/control.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'mubit/v1/control.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16mubit/v1/control.proto\x12\x08mubit.v1\"\x16\n\x03\x41\x63k\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\x1c\n\nRunRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"7\n\x10SubscribeRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x13\n\x0b\x65vent_types\x18\x02 \x03(\t\"h\n\x05\x45vent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0e\n\x06run_id\x18\x03 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x04 \x01(\t\x12\x0f\n\x07payload\x18\x05 \x01(\t\x12\x12\n\ncreated_at\x18\x06 \x01(\t\"I\n\x08RunScope\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x16\n\x0elinked_run_ids\x18\x02 \x03(\t\x12\x15\n\rowner_user_id\x18\x03 \x01(\x04\"\xb3\x01\n\rAgentIdentity\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x14\n\x0c\x63\x61pabilities\x18\x03 \x03(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x14\n\x0cheartbeat_at\x18\x05 \x01(\t\x12\x13\n\x0bread_scopes\x18\x06 \x03(\t\x12\x14\n\x0cwrite_scopes\x18\x07 \x03(\t\x12\x1b\n\x13shared_memory_lanes\x18\x08 \x03(\t\"\x87\x01\n\x0e\x41\x63tivityRecord\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\t\x12\x11\n\ttool_name\x18\x03 \x01(\t\x12\x11\n\tinput_ref\x18\x04 \x01(\t\x12\x12\n\noutput_ref\x18\x05 \x01(\t\x12\n\n\x02ts\x18\x06 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x07 \x01(\t\"\x92\x01\n\x0bRunSnapshot\x12\x0f\n\x07summary\x18\x01 \x01(\t\x12\r\n\x05\x66\x61\x63ts\x18\x02 \x03(\t\x12\x15\n\runcertainties\x18\x03 \x03(\t\x12\x10\n\x08\x62lockers\x18\x04 \x03(\t\x12\x10\n\x08progress\x18\x05 \x03(\t\x12\x14\n\x0cnext_actions\x18\x06 \x03(\t\x12\x12\n\nupdated_at\x18\x07 \x01(\t\"\x8a\x01\n\x11PromotionDecision\x12\x18\n\x10source_record_id\x18\x01 \x01(\t\x12\x0e\n\x06target\x18\x02 \x01(\t\x12\x12\n\nconfidence\x18\x03 \x01(\x02\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x13\n\x0bpolicy_rule\x18\x05 \x01(\t\x12\x12\n\ncreated_at\x18\x06 \x01(\t\"k\n\x0bLlmOverride\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\r\n\x05model\x18\x02 \x01(\t\x12\x13\n\x0btemperature\x18\x03 \x01(\x02\x12\x12\n\nmax_tokens\x18\x04 \x01(\r\x12\x12\n\ntimeout_ms\x18\x05 \x01(\x04\"z\n\rControlStatus\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0f\n\x07healthy\x18\x02 \x01(\x08\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\r\n\x05model\x18\x04 \x01(\t\x12\x12\n\nlast_error\x18\x05 \x01(\t\x12\x12\n\nupdated_at\x18\x06 \x01(\t\"\xb4\x01\n\x14\x41gentRegisterRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x02 \x01(\t\x12\x0c\n\x04role\x18\x03 \x01(\t\x12\x14\n\x0c\x63\x61pabilities\x18\x04 \x03(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x13\n\x0bread_scopes\x18\x06 \x03(\t\x12\x14\n\x0cwrite_scopes\x18\x07 \x03(\t\x12\x1b\n\x13shared_memory_lanes\x18\x08 \x03(\t\"P\n\x15\x41gentRegisterResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12&\n\x05\x61gent\x18\x02 \x01(\x0b\x32\x17.mubit.v1.AgentIdentity\"I\n\x15\x41gentHeartbeatRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x89\x01\n\x15\x41\x63tivityAppendRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x02 \x01(\t\x12*\n\x08\x61\x63tivity\x18\x03 \x01(\x0b\x32\x18.mubit.v1.ActivityRecord\x12\"\n\x03llm\x18\x04 \x01(\x0b\x32\x15.mubit.v1.LlmOverride\";\n\x16\x41\x63tivityAppendResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\"q\n\x12RunSnapshotRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x16\n\x0etimeline_limit\x18\x02 \x01(\x04\x12\x0f\n\x07refresh\x18\x03 \x01(\x08\x12\"\n\x03llm\x18\x04 \x01(\x0b\x32\x15.mubit.v1.LlmOverride\"\x8f\x02\n\x13RunSnapshotResponse\x12!\n\x05scope\x18\x01 \x01(\x0b\x32\x12.mubit.v1.RunScope\x12\'\n\x08snapshot\x18\x02 \x01(\x0b\x32\x15.mubit.v1.RunSnapshot\x12\'\n\x06\x61gents\x18\x03 \x03(\x0b\x32\x17.mubit.v1.AgentIdentity\x12!\n\x08timeline\x18\x04 \x03(\x0b\x32\x0f.mubit.v1.Event\x12/\n\npromotions\x18\x05 \x03(\x0b\x32\x1b.mubit.v1.PromotionDecision\x12/\n\x0e\x63ontrol_status\x18\x06 \x01(\x0b\x32\x17.mubit.v1.ControlStatus\"7\n\x0eLinkRunRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x15\n\rlinked_run_id\x18\x02 \x01(\t\"E\n\x0fLinkRunResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12!\n\x05scope\x18\x02 \x01(\x0b\x32\x12.mubit.v1.RunScope\"9\n\x10UnlinkRunRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x15\n\rlinked_run_id\x18\x02 \x01(\t\"G\n\x11UnlinkRunResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12!\n\x05scope\x18\x02 \x01(\x0b\x32\x12.mubit.v1.RunScope\"\xc1\x02\n\nIngestItem\x12\x0f\n\x07item_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x14\n\x0cpayload_json\x18\x04 \x01(\t\x12\x12\n\nhints_json\x18\x05 \x01(\t\x12\x15\n\rmetadata_json\x18\x06 \x01(\t\x12\x0e\n\x06intent\x18\x07 \x01(\t\x12\x13\n\x0blesson_type\x18\x08 \x01(\t\x12\x14\n\x0clesson_scope\x18\t \x01(\t\x12\x19\n\x11lesson_importance\x18\n \x01(\t\x12\x1e\n\x16lesson_conditions_json\x18\x0b \x01(\t\x12\x0f\n\x07user_id\x18\x0c \x01(\t\x12\x12\n\nupsert_key\x18\r \x01(\t\x12\x12\n\nimportance\x18\x0e \x01(\t\x12\x0e\n\x06source\x18\x14 \x01(\t\"\x81\x01\n\rIngestRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x02 \x01(\t\x12\x17\n\x0fidempotency_key\x18\x03 \x01(\t\x12\x10\n\x08parallel\x18\x04 \x01(\x08\x12#\n\x05items\x18\x05 \x03(\x0b\x32\x14.mubit.v1.IngestItem\"X\n\x0eIngestAccepted\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\x08\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x65\x64uplicated\x18\x03 \x01(\x08\x12\x0e\n\x06status\x18\x04 \x01(\t\"q\n\x16\x43ontrolBatchInsertItem\x12\x0f\n\x07item_id\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x15\n\rmetadata_json\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x11\n\tembedding\x18\x05 \x03(\x02\"q\n\x19\x43ontrolBatchInsertRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12/\n\x05items\x18\x02 \x03(\x0b\x32 .mubit.v1.ControlBatchInsertItem\x12\x13\n\x0b\x64\x65\x64uplicate\x18\x03 \x01(\x08\"`\n\x1c\x43ontrolBatchInsertItemResult\x12\x0f\n\x07item_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x0f\n\x07node_id\x18\x03 \x01(\x04\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"\x9d\x01\n\x1a\x43ontrolBatchInsertResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x12\x10\n\x08node_ids\x18\x03 \x03(\x04\x12<\n\x0citem_results\x18\x04 \x03(\x0b\x32&.mubit.v1.ControlBatchInsertItemResult\x12\x0f\n\x07message\x18\x05 \x01(\t\"5\n\x13GetIngestJobRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\"[\n\x11IngestWriteResult\x12\x13\n\x0bmemory_type\x18\x01 \x01(\t\x12\x11\n\trecord_id\x18\x02 \x01(\t\x12\x0f\n\x07success\x18\x03 \x01(\x08\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"\xc8\x01\n\x13IngestDecisionTrace\x12\x0f\n\x07item_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\x02 \x01(\t\x12\x16\n\x0eselected_types\x18\x03 \x03(\t\x12\x11\n\treasoning\x18\x04 \x01(\t\x12\x1e\n\x16\x65nriched_metadata_json\x18\x05 \x01(\t\x12+\n\x06writes\x18\x06 \x03(\x0b\x32\x1b.mubit.v1.IngestWriteResult\x12\x12\n\nconfidence\x18\x07 \x01(\x02\"\xf3\x01\n\x11IngestJobResponse\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x0e\n\x06run_id\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x0c\n\x04\x64one\x18\x04 \x01(\x08\x12\r\n\x05\x65rror\x18\x05 \x01(\t\x12\x12\n\ncreated_at\x18\x06 \x01(\t\x12\x12\n\nstarted_at\x18\x07 \x01(\t\x12\x13\n\x0b\x66inished_at\x18\x08 \x01(\t\x12-\n\x06traces\x18\t \x03(\x0b\x32\x1d.mubit.v1.IngestDecisionTrace\x12\x0f\n\x07ordered\x18\n \x01(\x08\x12\x14\n\x0c\x64\x65\x64uplicated\x18\x0b \x01(\x08\"*\n\x18GetRunIngestStatsRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"\xb7\x01\n\x10\x41gentIngestStats\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\x12\x11\n\tjob_count\x18\x02 \x01(\r\x12\x1b\n\x13\x63ompleted_job_count\x18\x03 \x01(\r\x12\x18\n\x10\x66\x61iled_job_count\x18\x04 \x01(\r\x12\x1e\n\x16\x64\x65\x64uplicated_job_count\x18\x05 \x01(\r\x12\x12\n\nitem_count\x18\x06 \x01(\r\x12\x13\n\x0blast_job_at\x18\x07 \x01(\t\"\xc5\x01\n\x16RunIngestStatsResponse\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x12\n\ntotal_jobs\x18\x02 \x01(\r\x12\x16\n\x0e\x63ompleted_jobs\x18\x03 \x01(\r\x12\x13\n\x0b\x66\x61iled_jobs\x18\x04 \x01(\r\x12\x19\n\x11\x64\x65\x64uplicated_jobs\x18\x05 \x01(\r\x12\x13\n\x0btotal_items\x18\x06 \x01(\r\x12*\n\x06\x61gents\x18\x07 \x03(\x0b\x32\x1a.mubit.v1.AgentIngestStats\"\xac\x02\n\x11\x41gentQueryRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12!\n\x04mode\x18\x04 \x01(\x0e\x32\x13.mubit.v1.QueryMode\x12.\n\x0b\x64irect_lane\x18\x05 \x01(\x0e\x32\x19.mubit.v1.DirectQueryLane\x12\x1b\n\x13include_linked_runs\x18\x06 \x01(\x08\x12\r\n\x05limit\x18\x07 \x01(\x04\x12\x11\n\tembedding\x18\x08 \x03(\x02\x12\x13\n\x0b\x65ntry_types\x18\t \x03(\t\x12\x1e\n\x16include_working_memory\x18\n \x01(\x08\x12\x0f\n\x07user_id\x18\x0b \x01(\t\x12\x10\n\x08\x61gent_id\x18\x0c \x01(\t\"\xe6\x01\n\rQueryEvidence\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\x02\x12\x0e\n\x06run_id\x18\x05 \x01(\t\x12\x12\n\nentry_type\x18\x06 \x01(\t\x12\x15\n\rmetadata_json\x18\x07 \x01(\t\x12\x16\n\x0eretrieval_mode\x18\x08 \x01(\t\x12\x14\n\x0creference_id\x18\t \x01(\t\x12\x15\n\rreferenceable\x18\n \x01(\x08\x12\x19\n\x11origin_entry_type\x18\x0b \x01(\t\"\xba\x01\n\x12\x41gentQueryResponse\x12\x14\n\x0c\x66inal_answer\x18\x01 \x01(\t\x12)\n\x08\x65vidence\x18\x02 \x03(\x0b\x32\x17.mubit.v1.QueryEvidence\x12\x12\n\nconfidence\x18\x03 \x01(\x02\x12\x0c\n\x04mode\x18\x04 \x01(\t\x12\x10\n\x08\x64\x65graded\x18\x05 \x01(\x08\x12\x16\n\x0e\x63onsulted_runs\x18\x06 \x03(\t\x12\x17\n\x0frouting_summary\x18\x07 \x01(\t\"i\n\x0f\x44iagnoseRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x12\n\nerror_text\x18\x02 \x01(\t\x12\x12\n\nerror_type\x18\x03 \x01(\t\x12\r\n\x05limit\x18\x04 \x01(\x04\x12\x0f\n\x07user_id\x18\x05 \x01(\t\"t\n\x10\x44iagnoseResponse\x12\x30\n\x0f\x66\x61ilure_lessons\x18\x01 \x03(\x0b\x32\x17.mubit.v1.QueryEvidence\x12\x0f\n\x07summary\x18\x02 \x01(\t\x12\x1d\n\x15total_failure_lessons\x18\x03 \x01(\r\"V\n\x12SetVariableRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nvalue_json\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\"2\n\x12GetVariableRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x96\x01\n\x10VariableResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nvalue_json\x18\x02 \x01(\t\x12\x10\n\x08var_type\x18\x03 \x01(\t\x12\x12\n\ncreated_at\x18\x04 \x01(\t\x12\x14\n\x0clast_updated\x18\x05 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_count\x18\x06 \x01(\x04\x12\x0e\n\x06source\x18\x07 \x01(\t\"&\n\x14ListVariablesRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"F\n\x15ListVariablesResponse\x12-\n\tvariables\x18\x01 \x03(\x0b\x32\x1a.mubit.v1.VariableResponse\"5\n\x15\x44\x65leteVariableRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"I\n\x14\x44\x65\x66ineConceptRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bschema_json\x18\x03 \x01(\t\"%\n\x13ListConceptsRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\",\n\x07\x43oncept\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bschema_json\x18\x02 \x01(\t\";\n\x14ListConceptsResponse\x12#\n\x08\x63oncepts\x18\x01 \x03(\x0b\x32\x11.mubit.v1.Concept\"r\n\x0e\x41\x64\x64GoalRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08priority\x18\x03 \x01(\t\x12\x11\n\tparent_id\x18\x04 \x01(\t\x12\x16\n\x0eparent_goal_id\x18\x05 \x01(\t\"x\n\x0cGoalResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08priority\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x11\n\tparent_id\x18\x05 \x01(\t\x12\x12\n\ncreated_at\x18\x06 \x01(\t\"D\n\x11UpdateGoalRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0f\n\x07goal_id\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"9\n\x10ListGoalsRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x15\n\rstatus_filter\x18\x02 \x01(\t\":\n\x11ListGoalsResponse\x12%\n\x05goals\x18\x01 \x03(\x0b\x32\x16.mubit.v1.GoalResponse\":\n\x12GetGoalTreeRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x14\n\x0croot_goal_id\x18\x02 \x01(\t\"e\n\x08GoalNode\x12$\n\x04goal\x18\x01 \x01(\x0b\x32\x16.mubit.v1.GoalResponse\x12$\n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x12.mubit.v1.GoalNode\x12\r\n\x05\x64\x65pth\x18\x03 \x01(\r\"8\n\x13GetGoalTreeResponse\x12!\n\x05goals\x18\x01 \x03(\x0b\x32\x12.mubit.v1.GoalNode\"[\n\rActionRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x02 \x01(\t\x12\x13\n\x0b\x61\x63tion_type\x18\x03 \x01(\t\x12\x13\n\x0b\x61\x63tion_json\x18\x04 \x01(\t\"m\n\x0e\x41\x63tionResponse\x12\x11\n\taction_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x13\n\x0bresult_json\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\x12\x13\n\x0b\x64uration_ms\x18\x05 \x01(\x04\"M\n\x10\x41\x63tionLogRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x04\x12\x1a\n\x12\x61\x63tion_type_filter\x18\x03 \x01(\t\">\n\x11\x41\x63tionLogResponse\x12)\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x18.mubit.v1.ActionLogEntry\"\x9c\x01\n\x0e\x41\x63tionLogEntry\x12\x11\n\taction_id\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63tion_type\x18\x02 \x01(\t\x12\x13\n\x0b\x61\x63tion_json\x18\x03 \x01(\t\x12\x0f\n\x07success\x18\x04 \x01(\x08\x12\x13\n\x0bresult_json\x18\x05 \x01(\t\x12\x14\n\x0c\x63ycle_number\x18\x06 \x01(\x04\x12\x11\n\ttimestamp\x18\x07 \x01(\t\"b\n\x0fRunCycleRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x02 \x01(\t\x12-\n\ncandidates\x18\x03 \x03(\x0b\x32\x19.mubit.v1.ActionCandidate\"]\n\x0f\x41\x63tionCandidate\x12\x13\n\x0b\x61\x63tion_type\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63tion_json\x18\x02 \x01(\t\x12\r\n\x05score\x18\x03 \x01(\x02\x12\x11\n\trationale\x18\x04 \x01(\t\"\xd2\x01\n\rCycleResponse\x12\x14\n\x0c\x63ycle_number\x18\x01 \x01(\x04\x12\x32\n\x0fselected_action\x18\x02 \x01(\x0b\x32\x19.mubit.v1.ActionCandidate\x12/\n\raction_result\x18\x03 \x01(\x0b\x32\x18.mubit.v1.ActionResponse\x12\x18\n\x10planning_time_ms\x18\x04 \x01(\x04\x12\x19\n\x11\x65xecution_time_ms\x18\x05 \x01(\x04\x12\x11\n\ttimestamp\x18\x06 \x01(\t\"4\n\x13\x43ycleHistoryRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x04\"?\n\x14\x43ycleHistoryResponse\x12\'\n\x06\x63ycles\x18\x01 \x03(\x0b\x32\x17.mubit.v1.CycleResponse\"N\n\x0eReflectRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x1b\n\x13include_linked_runs\x18\x02 \x01(\x08\x12\x0f\n\x07user_id\x18\x03 \x01(\t\"\x7f\n\rReflectLesson\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x13\n\x0blesson_type\x18\x02 \x01(\t\x12\r\n\x05scope\x18\x03 \x01(\t\x12\x12\n\nimportance\x18\x04 \x01(\t\x12\x12\n\nconditions\x18\x05 \x03(\t\x12\x11\n\trationale\x18\x06 \x01(\t\"\x8a\x01\n\x0fReflectResponse\x12(\n\x07lessons\x18\x01 \x03(\x0b\x32\x17.mubit.v1.ReflectLesson\x12\x0f\n\x07summary\x18\x02 \x01(\t\x12\x12\n\nconfidence\x18\x03 \x01(\x02\x12\x10\n\x08\x64\x65graded\x18\x04 \x01(\x08\x12\x16\n\x0elessons_stored\x18\x05 \x01(\r\"g\n\x12ListLessonsRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\r\n\x05scope\x18\x02 \x01(\t\x12\x12\n\nimportance\x18\x03 \x01(\t\x12\r\n\x05limit\x18\x04 \x01(\x04\x12\x0f\n\x07user_id\x18\x05 \x01(\t\"\xb0\x01\n\x0bLessonEntry\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x13\n\x0blesson_type\x18\x03 \x01(\t\x12\r\n\x05scope\x18\x04 \x01(\t\x12\x12\n\nimportance\x18\x05 \x01(\t\x12\x12\n\nconditions\x18\x06 \x03(\t\x12\x11\n\trationale\x18\x07 \x01(\t\x12\x15\n\rsource_run_id\x18\x08 \x01(\t\x12\x0e\n\x06source\x18\t \x01(\t\"=\n\x13ListLessonsResponse\x12&\n\x07lessons\x18\x01 \x03(\x0b\x32\x15.mubit.v1.LessonEntry\"(\n\x13\x44\x65leteLessonRequest\x12\x11\n\tlesson_id\x18\x01 \x01(\t\"\xe0\x01\n\x0e\x43ontextRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x13\n\x0b\x65ntry_types\x18\x04 \x03(\t\x12\x1e\n\x16include_working_memory\x18\x05 \x01(\x08\x12\x0e\n\x06\x66ormat\x18\x06 \x01(\t\x12\r\n\x05limit\x18\x07 \x01(\x04\x12\x18\n\x10max_token_budget\x18\x08 \x01(\r\x12\x10\n\x08\x61gent_id\x18\t \x01(\t\x12\x0c\n\x04mode\x18\n \x01(\t\x12\x10\n\x08sections\x18\x0b \x03(\t\"u\n\x15\x43ontextSectionSummary\x12\x14\n\x0csection_name\x18\x01 \x01(\t\x12\x12\n\nitem_count\x18\x02 \x01(\r\x12\x18\n\x10top_item_preview\x18\x03 \x01(\t\x12\x18\n\x10\x65stimated_tokens\x18\x04 \x01(\r\"\x8a\x05\n\x0f\x43ontextResponse\x12\x15\n\rcontext_block\x18\x01 \x01(\t\x12\x16\n\x0etoken_estimate\x18\x02 \x01(\r\x12(\n\x07sources\x18\x03 \x03(\x0b\x32\x17.mubit.v1.QueryEvidence\x12\x13\n\x0b\x62udget_used\x18\x04 \x01(\r\x12\x18\n\x10\x62udget_remaining\x18\x05 \x01(\r\x12:\n\x11section_summaries\x18\x06 \x03(\x0b\x32\x1f.mubit.v1.ContextSectionSummary\x12[\n\x1bsource_counts_by_entry_type\x18\x07 \x03(\x0b\x32\x36.mubit.v1.ContextResponse.SourceCountsByEntryTypeEntry\x12\x63\n\x1fsource_counts_by_retrieval_mode\x18\x08 \x03(\x0b\x32:.mubit.v1.ContextResponse.SourceCountsByRetrievalModeEntry\x12&\n\x1e\x65vidence_candidates_considered\x18\t \x01(\r\x12\"\n\x1a\x65vidence_dropped_by_budget\x18\n \x01(\r\x12!\n\x19\x65xact_references_surfaced\x18\x0b \x01(\r\x1a>\n\x1cSourceCountsByEntryTypeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\x1a\x42\n SourceCountsByRetrievalModeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\"\x84\x02\n\x13\x41rchiveBlockRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x15\n\rartifact_kind\x18\x03 \x01(\t\x12\x15\n\rmetadata_json\x18\x04 \x01(\t\x12\x0f\n\x07user_id\x18\x05 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x06 \x01(\t\x12\x17\n\x0forigin_agent_id\x18\x07 \x01(\t\x12\x19\n\x11source_attempt_id\x18\x08 \x01(\t\x12\x13\n\x0bsource_tool\x18\t \x01(\t\x12\x0e\n\x06labels\x18\n \x03(\t\x12\x0e\n\x06\x66\x61mily\x18\x0b \x01(\t\x12\x12\n\nimportance\x18\x0c \x01(\t\"Q\n\x14\x41rchiveBlockResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x14\n\x0creference_id\x18\x02 \x01(\t\x12\x12\n\nentry_type\x18\x03 \x01(\t\"]\n\x12\x44\x65referenceRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x14\n\x0creference_id\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x04 \x01(\t\"O\n\x13\x44\x65referenceResponse\x12\r\n\x05\x66ound\x18\x01 \x01(\x08\x12)\n\x08\x65vidence\x18\x02 \x01(\x0b\x32\x17.mubit.v1.QueryEvidence\"c\n\x13MemoryHealthRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x1c\n\x14stale_threshold_days\x18\x03 \x01(\r\x12\r\n\x05limit\x18\x04 \x01(\r\"\x81\x01\n\x13LessonContradiction\x12\x13\n\x0blesson_a_id\x18\x01 \x01(\t\x12\x13\n\x0blesson_b_id\x18\x02 \x01(\t\x12\x12\n\nsimilarity\x18\x03 \x01(\x02\x12\x15\n\rlesson_a_type\x18\x04 \x01(\t\x12\x15\n\rlesson_b_type\x18\x05 \x01(\t\"c\n\rSectionHealth\x12\x14\n\x0csection_name\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\r\x12\x16\n\x0e\x61vg_confidence\x18\x03 \x01(\x02\x12\x15\n\ravg_age_hours\x18\x04 \x01(\x02\"\xcc\x02\n\x14MemoryHealthResponse\x12\x45\n\x0c\x65ntry_counts\x18\x01 \x03(\x0b\x32/.mubit.v1.MemoryHealthResponse.EntryCountsEntry\x12\x15\n\rstale_entries\x18\x02 \x01(\r\x12\x35\n\x0e\x63ontradictions\x18\x03 \x03(\x0b\x32\x1d.mubit.v1.LessonContradiction\x12\x1c\n\x14low_confidence_count\x18\x04 \x01(\r\x12\x1c\n\x14promotion_candidates\x18\x05 \x03(\t\x12/\n\x0esection_health\x18\x06 \x03(\x0b\x32\x17.mubit.v1.SectionHealth\x1a\x32\n\x10\x45ntryCountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\"\x86\x01\n\x11\x43heckpointRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\x18\n\x10\x63ontext_snapshot\x18\x03 \x01(\t\x12\x15\n\rmetadata_json\x18\x04 \x01(\t\x12\x0f\n\x07user_id\x18\x05 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x06 \x01(\t\"T\n\x12\x43heckpointResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rcheckpoint_id\x18\x02 \x01(\t\x12\x16\n\x0etoken_estimate\x18\x03 \x01(\r\"#\n\x11ListAgentsRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"=\n\x12ListAgentsResponse\x12\'\n\x06\x61gents\x18\x01 \x03(\x0b\x32\x17.mubit.v1.AgentIdentity\"\xb0\x01\n\x0eHandoffRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\t\x12\x15\n\rfrom_agent_id\x18\x03 \x01(\t\x12\x13\n\x0bto_agent_id\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\t\x12\x18\n\x10requested_action\x18\x06 \x01(\t\x12\x15\n\rmetadata_json\x18\x07 \x01(\t\x12\x0f\n\x07user_id\x18\x08 \x01(\t\"6\n\x0fHandoffResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x12\n\nhandoff_id\x18\x02 \x01(\t\"\x97\x01\n\x0f\x46\x65\x65\x64\x62\x61\x63kRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x12\n\nhandoff_id\x18\x02 \x01(\t\x12\x0f\n\x07verdict\x18\x03 \x01(\t\x12\x10\n\x08\x63omments\x18\x04 \x01(\t\x12\x15\n\rfrom_agent_id\x18\x05 \x01(\t\x12\x15\n\rmetadata_json\x18\x06 \x01(\t\x12\x0f\n\x07user_id\x18\x07 \x01(\t\"8\n\x10\x46\x65\x65\x64\x62\x61\x63kResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x13\n\x0b\x66\x65\x65\x64\x62\x61\x63k_id\x18\x02 \x01(\t\"\x93\x01\n\x14RecordOutcomeRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x14\n\x0creference_id\x18\x02 \x01(\t\x12\x0f\n\x07outcome\x18\x03 \x01(\t\x12\x0e\n\x06signal\x18\x04 \x01(\x02\x12\x11\n\trationale\x18\x05 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x06 \x01(\t\x12\x0f\n\x07user_id\x18\x07 \x01(\t\"a\n\x15RecordOutcomeResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x1b\n\x13reinforcement_count\x18\x02 \x01(\x05\x12\x1a\n\x12updated_confidence\x18\x03 \x01(\x02\"i\n\x18SurfaceStrategiesRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x14\n\x0clesson_types\x18\x02 \x03(\t\x12\x16\n\x0emax_strategies\x18\x03 \x01(\r\x12\x0f\n\x07user_id\x18\x04 \x01(\t\"\xda\x01\n\x10\x45mergentStrategy\x12\x13\n\x0bstrategy_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1f\n\x17supporting_lesson_count\x18\x03 \x01(\r\x12\x16\n\x0e\x61vg_confidence\x18\x04 \x01(\x02\x12\x19\n\x11\x61vg_reinforcement\x18\x05 \x01(\x02\x12\x1c\n\x14\x64ominant_lesson_type\x18\x06 \x01(\t\x12\x16\n\x0e\x64ominant_scope\x18\x07 \x01(\t\x12\x12\n\nlesson_ids\x18\x08 \x03(\t\"K\n\x19SurfaceStrategiesResponse\x12.\n\nstrategies\x18\x01 \x03(\x0b\x32\x1a.mubit.v1.EmergentStrategy*L\n\tQueryMode\x12\x1a\n\x16QUERY_MODE_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x41GENT_ROUTED\x10\x01\x12\x11\n\rDIRECT_BYPASS\x10\x02*I\n\x0f\x44irectQueryLane\x12!\n\x1d\x44IRECT_QUERY_LANE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSEMANTIC_SEARCH\x10\x01\x32\x9b\x17\n\x0e\x43ontrolService\x12:\n\x0bSetVariable\x12\x1c.mubit.v1.SetVariableRequest\x1a\r.mubit.v1.Ack\x12G\n\x0bGetVariable\x12\x1c.mubit.v1.GetVariableRequest\x1a\x1a.mubit.v1.VariableResponse\x12P\n\rListVariables\x12\x1e.mubit.v1.ListVariablesRequest\x1a\x1f.mubit.v1.ListVariablesResponse\x12@\n\x0e\x44\x65leteVariable\x12\x1f.mubit.v1.DeleteVariableRequest\x1a\r.mubit.v1.Ack\x12>\n\rDefineConcept\x12\x1e.mubit.v1.DefineConceptRequest\x1a\r.mubit.v1.Ack\x12M\n\x0cListConcepts\x12\x1d.mubit.v1.ListConceptsRequest\x1a\x1e.mubit.v1.ListConceptsResponse\x12;\n\x07\x41\x64\x64Goal\x12\x18.mubit.v1.AddGoalRequest\x1a\x16.mubit.v1.GoalResponse\x12\x38\n\nUpdateGoal\x12\x1b.mubit.v1.UpdateGoalRequest\x1a\r.mubit.v1.Ack\x12\x44\n\tListGoals\x12\x1a.mubit.v1.ListGoalsRequest\x1a\x1b.mubit.v1.ListGoalsResponse\x12J\n\x0bGetGoalTree\x12\x1c.mubit.v1.GetGoalTreeRequest\x1a\x1d.mubit.v1.GetGoalTreeResponse\x12\x41\n\x0cSubmitAction\x12\x17.mubit.v1.ActionRequest\x1a\x18.mubit.v1.ActionResponse\x12G\n\x0cGetActionLog\x12\x1a.mubit.v1.ActionLogRequest\x1a\x1b.mubit.v1.ActionLogResponse\x12>\n\x08RunCycle\x12\x19.mubit.v1.RunCycleRequest\x1a\x17.mubit.v1.CycleResponse\x12P\n\x0fGetCycleHistory\x12\x1d.mubit.v1.CycleHistoryRequest\x1a\x1e.mubit.v1.CycleHistoryResponse\x12\x30\n\tDeleteRun\x12\x14.mubit.v1.RunRequest\x1a\r.mubit.v1.Ack\x12:\n\tSubscribe\x12\x1a.mubit.v1.SubscribeRequest\x1a\x0f.mubit.v1.Event0\x01\x12P\n\rRegisterAgent\x12\x1e.mubit.v1.AgentRegisterRequest\x1a\x1f.mubit.v1.AgentRegisterResponse\x12@\n\x0e\x41gentHeartbeat\x12\x1f.mubit.v1.AgentHeartbeatRequest\x1a\r.mubit.v1.Ack\x12S\n\x0e\x41ppendActivity\x12\x1f.mubit.v1.ActivityAppendRequest\x1a .mubit.v1.ActivityAppendResponse\x12M\n\x0eGetRunSnapshot\x12\x1c.mubit.v1.RunSnapshotRequest\x1a\x1d.mubit.v1.RunSnapshotResponse\x12>\n\x07LinkRun\x12\x18.mubit.v1.LinkRunRequest\x1a\x19.mubit.v1.LinkRunResponse\x12\x44\n\tUnlinkRun\x12\x1a.mubit.v1.UnlinkRunRequest\x1a\x1b.mubit.v1.UnlinkRunResponse\x12;\n\x06Ingest\x12\x17.mubit.v1.IngestRequest\x1a\x18.mubit.v1.IngestAccepted\x12X\n\x0b\x42\x61tchInsert\x12#.mubit.v1.ControlBatchInsertRequest\x1a$.mubit.v1.ControlBatchInsertResponse\x12J\n\x0cGetIngestJob\x12\x1d.mubit.v1.GetIngestJobRequest\x1a\x1b.mubit.v1.IngestJobResponse\x12Y\n\x11GetRunIngestStats\x12\".mubit.v1.GetRunIngestStatsRequest\x1a .mubit.v1.RunIngestStatsResponse\x12\x42\n\x05Query\x12\x1b.mubit.v1.AgentQueryRequest\x1a\x1c.mubit.v1.AgentQueryResponse\x12\x41\n\x08\x44iagnose\x12\x19.mubit.v1.DiagnoseRequest\x1a\x1a.mubit.v1.DiagnoseResponse\x12>\n\x07Reflect\x12\x18.mubit.v1.ReflectRequest\x1a\x19.mubit.v1.ReflectResponse\x12J\n\x0bListLessons\x12\x1c.mubit.v1.ListLessonsRequest\x1a\x1d.mubit.v1.ListLessonsResponse\x12<\n\x0c\x44\x65leteLesson\x12\x1d.mubit.v1.DeleteLessonRequest\x1a\r.mubit.v1.Ack\x12\x41\n\nGetContext\x12\x18.mubit.v1.ContextRequest\x1a\x19.mubit.v1.ContextResponse\x12M\n\x0c\x41rchiveBlock\x12\x1d.mubit.v1.ArchiveBlockRequest\x1a\x1e.mubit.v1.ArchiveBlockResponse\x12J\n\x0b\x44\x65reference\x12\x1c.mubit.v1.DereferenceRequest\x1a\x1d.mubit.v1.DereferenceResponse\x12P\n\x0fGetMemoryHealth\x12\x1d.mubit.v1.MemoryHealthRequest\x1a\x1e.mubit.v1.MemoryHealthResponse\x12G\n\nCheckpoint\x12\x1b.mubit.v1.CheckpointRequest\x1a\x1c.mubit.v1.CheckpointResponse\x12G\n\nListAgents\x12\x1b.mubit.v1.ListAgentsRequest\x1a\x1c.mubit.v1.ListAgentsResponse\x12\x44\n\rCreateHandoff\x12\x18.mubit.v1.HandoffRequest\x1a\x19.mubit.v1.HandoffResponse\x12G\n\x0eSubmitFeedback\x12\x19.mubit.v1.FeedbackRequest\x1a\x1a.mubit.v1.FeedbackResponse\x12P\n\rRecordOutcome\x12\x1e.mubit.v1.RecordOutcomeRequest\x1a\x1f.mubit.v1.RecordOutcomeResponse\x12\\\n\x11SurfaceStrategies\x12\".mubit.v1.SurfaceStrategiesRequest\x1a#.mubit.v1.SurfaceStrategiesResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mubit.v1.control_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CONTEXTRESPONSE_SOURCECOUNTSBYENTRYTYPEENTRY']._loaded_options = None
  _globals['_CONTEXTRESPONSE_SOURCECOUNTSBYENTRYTYPEENTRY']._serialized_options = b'8\001'
  _globals['_CONTEXTRESPONSE_SOURCECOUNTSBYRETRIEVALMODEENTRY']._loaded_options = None
  _globals['_CONTEXTRESPONSE_SOURCECOUNTSBYRETRIEVALMODEENTRY']._serialized_options = b'8\001'
  _globals['_MEMORYHEALTHRESPONSE_ENTRYCOUNTSENTRY']._loaded_options = None
  _globals['_MEMORYHEALTHRESPONSE_ENTRYCOUNTSENTRY']._serialized_options = b'8\001'
  _globals['_QUERYMODE']._serialized_start=12087
  _globals['_QUERYMODE']._serialized_end=12163
  _globals['_DIRECTQUERYLANE']._serialized_start=12165
  _globals['_DIRECTQUERYLANE']._serialized_end=12238
  _globals['_ACK']._serialized_start=36
  _globals['_ACK']._serialized_end=58
  _globals['_RUNREQUEST']._serialized_start=60
  _globals['_RUNREQUEST']._serialized_end=88
  _globals['_SUBSCRIBEREQUEST']._serialized_start=90
  _globals['_SUBSCRIBEREQUEST']._serialized_end=145
  _globals['_EVENT']._serialized_start=147
  _globals['_EVENT']._serialized_end=251
  _globals['_RUNSCOPE']._serialized_start=253
  _globals['_RUNSCOPE']._serialized_end=326
  _globals['_AGENTIDENTITY']._serialized_start=329
  _globals['_AGENTIDENTITY']._serialized_end=508
  _globals['_ACTIVITYRECORD']._serialized_start=511
  _globals['_ACTIVITYRECORD']._serialized_end=646
  _globals['_RUNSNAPSHOT']._serialized_start=649
  _globals['_RUNSNAPSHOT']._serialized_end=795
  _globals['_PROMOTIONDECISION']._serialized_start=798
  _globals['_PROMOTIONDECISION']._serialized_end=936
  _globals['_LLMOVERRIDE']._serialized_start=938
  _globals['_LLMOVERRIDE']._serialized_end=1045
  _globals['_CONTROLSTATUS']._serialized_start=1047
  _globals['_CONTROLSTATUS']._serialized_end=1169
  _globals['_AGENTREGISTERREQUEST']._serialized_start=1172
  _globals['_AGENTREGISTERREQUEST']._serialized_end=1352
  _globals['_AGENTREGISTERRESPONSE']._serialized_start=1354
  _globals['_AGENTREGISTERRESPONSE']._serialized_end=1434
  _globals['_AGENTHEARTBEATREQUEST']._serialized_start=1436
  _globals['_AGENTHEARTBEATREQUEST']._serialized_end=1509
  _globals['_ACTIVITYAPPENDREQUEST']._serialized_start=1512
  _globals['_ACTIVITYAPPENDREQUEST']._serialized_end=1649
  _globals['_ACTIVITYAPPENDRESPONSE']._serialized_start=1651
  _globals['_ACTIVITYAPPENDRESPONSE']._serialized_end=1710
  _globals['_RUNSNAPSHOTREQUEST']._serialized_start=1712
  _globals['_RUNSNAPSHOTREQUEST']._serialized_end=1825
  _globals['_RUNSNAPSHOTRESPONSE']._serialized_start=1828
  _globals['_RUNSNAPSHOTRESPONSE']._serialized_end=2099
  _globals['_LINKRUNREQUEST']._serialized_start=2101
  _globals['_LINKRUNREQUEST']._serialized_end=2156
  _globals['_LINKRUNRESPONSE']._serialized_start=2158
  _globals['_LINKRUNRESPONSE']._serialized_end=2227
  _globals['_UNLINKRUNREQUEST']._serialized_start=2229
  _globals['_UNLINKRUNREQUEST']._serialized_end=2286
  _globals['_UNLINKRUNRESPONSE']._serialized_start=2288
  _globals['_UNLINKRUNRESPONSE']._serialized_end=2359
  _globals['_INGESTITEM']._serialized_start=2362
  _globals['_INGESTITEM']._serialized_end=2683
  _globals['_INGESTREQUEST']._serialized_start=2686
  _globals['_INGESTREQUEST']._serialized_end=2815
  _globals['_INGESTACCEPTED']._serialized_start=2817
  _globals['_INGESTACCEPTED']._serialized_end=2905
  _globals['_CONTROLBATCHINSERTITEM']._serialized_start=2907
  _globals['_CONTROLBATCHINSERTITEM']._serialized_end=3020
  _globals['_CONTROLBATCHINSERTREQUEST']._serialized_start=3022
  _globals['_CONTROLBATCHINSERTREQUEST']._serialized_end=3135
  _globals['_CONTROLBATCHINSERTITEMRESULT']._serialized_start=3137
  _globals['_CONTROLBATCHINSERTITEMRESULT']._serialized_end=3233
  _globals['_CONTROLBATCHINSERTRESPONSE']._serialized_start=3236
  _globals['_CONTROLBATCHINSERTRESPONSE']._serialized_end=3393
  _globals['_GETINGESTJOBREQUEST']._serialized_start=3395
  _globals['_GETINGESTJOBREQUEST']._serialized_end=3448
  _globals['_INGESTWRITERESULT']._serialized_start=3450
  _globals['_INGESTWRITERESULT']._serialized_end=3541
  _globals['_INGESTDECISIONTRACE']._serialized_start=3544
  _globals['_INGESTDECISIONTRACE']._serialized_end=3744
  _globals['_INGESTJOBRESPONSE']._serialized_start=3747
  _globals['_INGESTJOBRESPONSE']._serialized_end=3990
  _globals['_GETRUNINGESTSTATSREQUEST']._serialized_start=3992
  _globals['_GETRUNINGESTSTATSREQUEST']._serialized_end=4034
  _globals['_AGENTINGESTSTATS']._serialized_start=4037
  _globals['_AGENTINGESTSTATS']._serialized_end=4220
  _globals['_RUNINGESTSTATSRESPONSE']._serialized_start=4223
  _globals['_RUNINGESTSTATSRESPONSE']._serialized_end=4420
  _globals['_AGENTQUERYREQUEST']._serialized_start=4423
  _globals['_AGENTQUERYREQUEST']._serialized_end=4723
  _globals['_QUERYEVIDENCE']._serialized_start=4726
  _globals['_QUERYEVIDENCE']._serialized_end=4956
  _globals['_AGENTQUERYRESPONSE']._serialized_start=4959
  _globals['_AGENTQUERYRESPONSE']._serialized_end=5145
  _globals['_DIAGNOSEREQUEST']._serialized_start=5147
  _globals['_DIAGNOSEREQUEST']._serialized_end=5252
  _globals['_DIAGNOSERESPONSE']._serialized_start=5254
  _globals['_DIAGNOSERESPONSE']._serialized_end=5370
  _globals['_SETVARIABLEREQUEST']._serialized_start=5372
  _globals['_SETVARIABLEREQUEST']._serialized_end=5458
  _globals['_GETVARIABLEREQUEST']._serialized_start=5460
  _globals['_GETVARIABLEREQUEST']._serialized_end=5510
  _globals['_VARIABLERESPONSE']._serialized_start=5513
  _globals['_VARIABLERESPONSE']._serialized_end=5663
  _globals['_LISTVARIABLESREQUEST']._serialized_start=5665
  _globals['_LISTVARIABLESREQUEST']._serialized_end=5703
  _globals['_LISTVARIABLESRESPONSE']._serialized_start=5705
  _globals['_LISTVARIABLESRESPONSE']._serialized_end=5775
  _globals['_DELETEVARIABLEREQUEST']._serialized_start=5777
  _globals['_DELETEVARIABLEREQUEST']._serialized_end=5830
  _globals['_DEFINECONCEPTREQUEST']._serialized_start=5832
  _globals['_DEFINECONCEPTREQUEST']._serialized_end=5905
  _globals['_LISTCONCEPTSREQUEST']._serialized_start=5907
  _globals['_LISTCONCEPTSREQUEST']._serialized_end=5944
  _globals['_CONCEPT']._serialized_start=5946
  _globals['_CONCEPT']._serialized_end=5990
  _globals['_LISTCONCEPTSRESPONSE']._serialized_start=5992
  _globals['_LISTCONCEPTSRESPONSE']._serialized_end=6051
  _globals['_ADDGOALREQUEST']._serialized_start=6053
  _globals['_ADDGOALREQUEST']._serialized_end=6167
  _globals['_GOALRESPONSE']._serialized_start=6169
  _globals['_GOALRESPONSE']._serialized_end=6289
  _globals['_UPDATEGOALREQUEST']._serialized_start=6291
  _globals['_UPDATEGOALREQUEST']._serialized_end=6359
  _globals['_LISTGOALSREQUEST']._serialized_start=6361
  _globals['_LISTGOALSREQUEST']._serialized_end=6418
  _globals['_LISTGOALSRESPONSE']._serialized_start=6420
  _globals['_LISTGOALSRESPONSE']._serialized_end=6478
  _globals['_GETGOALTREEREQUEST']._serialized_start=6480
  _globals['_GETGOALTREEREQUEST']._serialized_end=6538
  _globals['_GOALNODE']._serialized_start=6540
  _globals['_GOALNODE']._serialized_end=6641
  _globals['_GETGOALTREERESPONSE']._serialized_start=6643
  _globals['_GETGOALTREERESPONSE']._serialized_end=6699
  _globals['_ACTIONREQUEST']._serialized_start=6701
  _globals['_ACTIONREQUEST']._serialized_end=6792
  _globals['_ACTIONRESPONSE']._serialized_start=6794
  _globals['_ACTIONRESPONSE']._serialized_end=6903
  _globals['_ACTIONLOGREQUEST']._serialized_start=6905
  _globals['_ACTIONLOGREQUEST']._serialized_end=6982
  _globals['_ACTIONLOGRESPONSE']._serialized_start=6984
  _globals['_ACTIONLOGRESPONSE']._serialized_end=7046
  _globals['_ACTIONLOGENTRY']._serialized_start=7049
  _globals['_ACTIONLOGENTRY']._serialized_end=7205
  _globals['_RUNCYCLEREQUEST']._serialized_start=7207
  _globals['_RUNCYCLEREQUEST']._serialized_end=7305
  _globals['_ACTIONCANDIDATE']._serialized_start=7307
  _globals['_ACTIONCANDIDATE']._serialized_end=7400
  _globals['_CYCLERESPONSE']._serialized_start=7403
  _globals['_CYCLERESPONSE']._serialized_end=7613
  _globals['_CYCLEHISTORYREQUEST']._serialized_start=7615
  _globals['_CYCLEHISTORYREQUEST']._serialized_end=7667
  _globals['_CYCLEHISTORYRESPONSE']._serialized_start=7669
  _globals['_CYCLEHISTORYRESPONSE']._serialized_end=7732
  _globals['_REFLECTREQUEST']._serialized_start=7734
  _globals['_REFLECTREQUEST']._serialized_end=7812
  _globals['_REFLECTLESSON']._serialized_start=7814
  _globals['_REFLECTLESSON']._serialized_end=7941
  _globals['_REFLECTRESPONSE']._serialized_start=7944
  _globals['_REFLECTRESPONSE']._serialized_end=8082
  _globals['_LISTLESSONSREQUEST']._serialized_start=8084
  _globals['_LISTLESSONSREQUEST']._serialized_end=8187
  _globals['_LESSONENTRY']._serialized_start=8190
  _globals['_LESSONENTRY']._serialized_end=8366
  _globals['_LISTLESSONSRESPONSE']._serialized_start=8368
  _globals['_LISTLESSONSRESPONSE']._serialized_end=8429
  _globals['_DELETELESSONREQUEST']._serialized_start=8431
  _globals['_DELETELESSONREQUEST']._serialized_end=8471
  _globals['_CONTEXTREQUEST']._serialized_start=8474
  _globals['_CONTEXTREQUEST']._serialized_end=8698
  _globals['_CONTEXTSECTIONSUMMARY']._serialized_start=8700
  _globals['_CONTEXTSECTIONSUMMARY']._serialized_end=8817
  _globals['_CONTEXTRESPONSE']._serialized_start=8820
  _globals['_CONTEXTRESPONSE']._serialized_end=9470
  _globals['_CONTEXTRESPONSE_SOURCECOUNTSBYENTRYTYPEENTRY']._serialized_start=9340
  _globals['_CONTEXTRESPONSE_SOURCECOUNTSBYENTRYTYPEENTRY']._serialized_end=9402
  _globals['_CONTEXTRESPONSE_SOURCECOUNTSBYRETRIEVALMODEENTRY']._serialized_start=9404
  _globals['_CONTEXTRESPONSE_SOURCECOUNTSBYRETRIEVALMODEENTRY']._serialized_end=9470
  _globals['_ARCHIVEBLOCKREQUEST']._serialized_start=9473
  _globals['_ARCHIVEBLOCKREQUEST']._serialized_end=9733
  _globals['_ARCHIVEBLOCKRESPONSE']._serialized_start=9735
  _globals['_ARCHIVEBLOCKRESPONSE']._serialized_end=9816
  _globals['_DEREFERENCEREQUEST']._serialized_start=9818
  _globals['_DEREFERENCEREQUEST']._serialized_end=9911
  _globals['_DEREFERENCERESPONSE']._serialized_start=9913
  _globals['_DEREFERENCERESPONSE']._serialized_end=9992
  _globals['_MEMORYHEALTHREQUEST']._serialized_start=9994
  _globals['_MEMORYHEALTHREQUEST']._serialized_end=10093
  _globals['_LESSONCONTRADICTION']._serialized_start=10096
  _globals['_LESSONCONTRADICTION']._serialized_end=10225
  _globals['_SECTIONHEALTH']._serialized_start=10227
  _globals['_SECTIONHEALTH']._serialized_end=10326
  _globals['_MEMORYHEALTHRESPONSE']._serialized_start=10329
  _globals['_MEMORYHEALTHRESPONSE']._serialized_end=10661
  _globals['_MEMORYHEALTHRESPONSE_ENTRYCOUNTSENTRY']._serialized_start=10611
  _globals['_MEMORYHEALTHRESPONSE_ENTRYCOUNTSENTRY']._serialized_end=10661
  _globals['_CHECKPOINTREQUEST']._serialized_start=10664
  _globals['_CHECKPOINTREQUEST']._serialized_end=10798
  _globals['_CHECKPOINTRESPONSE']._serialized_start=10800
  _globals['_CHECKPOINTRESPONSE']._serialized_end=10884
  _globals['_LISTAGENTSREQUEST']._serialized_start=10886
  _globals['_LISTAGENTSREQUEST']._serialized_end=10921
  _globals['_LISTAGENTSRESPONSE']._serialized_start=10923
  _globals['_LISTAGENTSRESPONSE']._serialized_end=10984
  _globals['_HANDOFFREQUEST']._serialized_start=10987
  _globals['_HANDOFFREQUEST']._serialized_end=11163
  _globals['_HANDOFFRESPONSE']._serialized_start=11165
  _globals['_HANDOFFRESPONSE']._serialized_end=11219
  _globals['_FEEDBACKREQUEST']._serialized_start=11222
  _globals['_FEEDBACKREQUEST']._serialized_end=11373
  _globals['_FEEDBACKRESPONSE']._serialized_start=11375
  _globals['_FEEDBACKRESPONSE']._serialized_end=11431
  _globals['_RECORDOUTCOMEREQUEST']._serialized_start=11434
  _globals['_RECORDOUTCOMEREQUEST']._serialized_end=11581
  _globals['_RECORDOUTCOMERESPONSE']._serialized_start=11583
  _globals['_RECORDOUTCOMERESPONSE']._serialized_end=11680
  _globals['_SURFACESTRATEGIESREQUEST']._serialized_start=11682
  _globals['_SURFACESTRATEGIESREQUEST']._serialized_end=11787
  _globals['_EMERGENTSTRATEGY']._serialized_start=11790
  _globals['_EMERGENTSTRATEGY']._serialized_end=12008
  _globals['_SURFACESTRATEGIESRESPONSE']._serialized_start=12010
  _globals['_SURFACESTRATEGIESRESPONSE']._serialized_end=12085
  _globals['_CONTROLSERVICE']._serialized_start=12241
  _globals['_CONTROLSERVICE']._serialized_end=15212
# @@protoc_insertion_point(module_scope)
